CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_cosmology.c File Reference

CCL

Functions
ccl_test_cosmology.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`

## Functions
| CTEST_DATA (cosmology)
| CTEST_SETUP (cosmology)
| CTEST2 (cosmology, create_general_cosmo)
| CTEST2 (cosmology, create_lcdm_cosmo)

## Function Documentation

## ◆ CTEST2() [1/2]

CTEST2 | ( | cosmology | ,
|  | create_general_cosmo |
| ) |  |

## ◆ CTEST2() [2/2]

CTEST2 | ( | cosmology | ,
|  | create_lcdm_cosmo |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | cosmology |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | cosmology |  | ) |